@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Data::Hive;
+package Data::Hive 1.014;
 # ABSTRACT: convenient access to hierarchical data
-$Data::Hive::VERSION = '1.013';
+
 use Carp ();
 
 #pod =head1 SYNOPSIS
@@ -203,7 +203,7 @@ sub GET {
   my $value = $self->STORE->get($self->{path});
   return defined $value     ? $value
        : ! defined $default ? undef
-       : ref $default       ? $default->()
+       : ref $default       ? scalar $default->()
        :                      $default;
 }
 
@@ -458,7 +458,7 @@ Data::Hive - convenient access to hierarchical data
 
 =head1 VERSION
 
-version 1.013
+version 1.014
 
 =head1 SYNOPSIS
 
@@ -536,6 +536,16 @@ It is not legal to have an empty part in a hive path.
 
 =back
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 WHY??
 
 By using method access, the behavior of hives can be augmented as needed during
@@ -738,7 +748,7 @@ Hans Dieter Pearcey <hdp@cpan.org>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =back
 
