@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Data::Hive::PathPacker::Flexible;
+package Data::Hive::PathPacker::Flexible 1.014;
 # ABSTRACT: a path packer that can be customized with callbacks
-$Data::Hive::PathPacker::Flexible::VERSION = '1.013';
+
 use parent 'Data::Hive::PathPacker';
 
 #pod =head1 DESCRIPTION
@@ -101,7 +101,7 @@ Data::Hive::PathPacker::Flexible - a path packer that can be customized with cal
 
 =head1 VERSION
 
-version 1.013
+version 1.014
 
 =head1 DESCRIPTION
 
@@ -109,6 +109,16 @@ This class provides the Data::Hive::PathPacker interface, and the way in which
 paths are packed and unpacked can be defined by callbacks set during
 initialization.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 new
@@ -151,7 +161,7 @@ Hans Dieter Pearcey <hdp@cpan.org>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =back
 
