@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Data::Hive::Store;
+package Data::Hive::Store 1.014;
 # ABSTRACT: a backend storage driver for Data::Hive
-$Data::Hive::Store::VERSION = '1.013';
+
 use Carp ();
 
 #pod =head1 DESCRIPTION
@@ -105,13 +105,23 @@ Data::Hive::Store - a backend storage driver for Data::Hive
 
 =head1 VERSION
 
-version 1.013
+version 1.014
 
 =head1 DESCRIPTION
 
 Data::Hive::Store is a generic interface to a backend store
 for Data::Hive.
 
+=head1 PERL VERSION SUPPORT
+
+This module has a long-term perl support period.  That means it will not
+require a version of perl released fewer than five years ago.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 All methods are passed at least a 'path' (arrayref of namespace pieces).  Store
@@ -170,7 +180,7 @@ Hans Dieter Pearcey <hdp@cpan.org>
 
 =item *
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <rjbs@semiotic.systems>
 
 =back
 
